Documentation
¶
Index ¶
- type Bool
- func (v Bool) Bool() bool
- func (v Bool) GetValue() any
- func (v Bool) IsChanged() bool
- func (v Bool) IsFalse() bool
- func (v Bool) IsTrue() bool
- func (v Bool) IsZero() bool
- func (v Bool) MarshalBSONValue() (bsontype.Type, []byte, error)
- func (v Bool) MarshalJSON() ([]byte, error)
- func (v Bool) NotChanged() bool
- func (v *Bool) Pointer() *bool
- func (v *Bool) Set(value bool)
- func (v *Bool) SetValue(value any) error
- func (v *Bool) UnmarshalBSONValue(t bsontype.Type, data []byte) error
- func (v *Bool) UnmarshalJSON(data []byte) error
- func (v Bool) Value() bool
- type ObjectID
- func (v ObjectID) GetValue() any
- func (v ObjectID) Hex() string
- func (v ObjectID) IsChanged() bool
- func (v ObjectID) IsZero() bool
- func (v ObjectID) MarshalBSONValue() (bsontype.Type, []byte, error)
- func (v ObjectID) MarshalJSON() ([]byte, error)
- func (v ObjectID) NotChanged() bool
- func (v *ObjectID) Pointer() *primitive.ObjectID
- func (v *ObjectID) Set(value primitive.ObjectID)
- func (v *ObjectID) SetValue(value any) error
- func (v ObjectID) String() string
- func (v *ObjectID) UnmarshalBSONValue(t bsontype.Type, data []byte) error
- func (v *ObjectID) UnmarshalJSON(data []byte) error
- func (v ObjectID) Value() primitive.ObjectID
- type String
- func (v String) GetValue() any
- func (v String) IsChanged() bool
- func (v String) IsZero() bool
- func (v String) MarshalBSONValue() (bsontype.Type, []byte, error)
- func (v String) MarshalJSON() ([]byte, error)
- func (v String) NotChanged() bool
- func (v *String) Pointer() *string
- func (v *String) Set(value string)
- func (v *String) SetValue(value any) error
- func (v String) String() string
- func (v *String) UnmarshalBSONValue(t bsontype.Type, data []byte) error
- func (v *String) UnmarshalJSON(data []byte) error
- func (v String) Value() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bool ¶ added in v0.1.0
type Bool struct {
// contains filtered or unexported fields
}
Bool tracks changes to a value since it has been loaded into memory
func (Bool) GetValue ¶ added in v0.1.0
GetValue implements schema.BoolGetter and returns the current value
func (Bool) IsChanged ¶ added in v0.1.0
IsChanged returns TRUE if the value has changed since it was loaded
func (Bool) IsZero ¶ added in v0.1.0
IsZero returns TRUE if the current value is the zero value for this type
func (Bool) MarshalBSONValue ¶ added in v0.1.0
MarshalBSONValue implements the bson.ValueMarshaler interface
func (Bool) MarshalJSON ¶ added in v0.1.0
MarshalJSON implements the json.Marshaler interface and serializes the Slice into a JSON array
func (Bool) NotChanged ¶ added in v0.1.0
NotChanged returns TRUE if the value has not changed since it was loaded
func (*Bool) SetValue ¶ added in v0.1.0
SetValue implements schema.BoolSetter and updates the current value, tracking changes to the added and deleted lists.
func (*Bool) UnmarshalBSONValue ¶ added in v0.1.0
UnmarshalBSONValue implements the bson.ValueUnmarshaler interface
func (*Bool) UnmarshalJSON ¶ added in v0.1.0
UnmarshalJSON implements the json.Unmarshaler interface and deserializes the Slice from a JSON array
type ObjectID ¶
type ObjectID struct {
// contains filtered or unexported fields
}
ObjectID tracks changes to a value since it has been loaded into memory
func NewObjectID ¶
NewObjectID returns a fully initialized Slice object
func (ObjectID) MarshalBSONValue ¶
MarshalBSONValue implements the bson.ValueMarshaler interface
func (ObjectID) MarshalJSON ¶
MarshalJSON implements the json.Marshaler interface and serializes the Slice into a JSON array
func (ObjectID) NotChanged ¶
NotChanged returns TRUE if the value has not changed since it was loaded
func (*ObjectID) SetValue ¶
SetValue implements schema.ObjectIDSetter and updates the current value, tracking changes to the added and deleted lists.
func (*ObjectID) UnmarshalBSONValue ¶
UnmarshalBSONValue implements the bson.ValueUnmarshaler interface
func (*ObjectID) UnmarshalJSON ¶
UnmarshalJSON implements the json.Unmarshaler interface and deserializes the Slice from a JSON array
type String ¶
type String struct {
// contains filtered or unexported fields
}
String tracks changes to a value since it has been loaded into memory
func (String) MarshalBSONValue ¶
MarshalBSONValue implements the bson.ValueMarshaler interface
func (String) MarshalJSON ¶
MarshalJSON implements the json.Marshaler interface and serializes the Slice into a JSON array
func (String) NotChanged ¶
NotChanged returns TRUE if the value has not changed since it was loaded
func (*String) SetValue ¶
SetValue implements schema.StringSetter and updates the current value, tracking changes to the added and deleted lists.
func (*String) UnmarshalBSONValue ¶
UnmarshalBSONValue implements the bson.ValueUnmarshaler interface
func (*String) UnmarshalJSON ¶
UnmarshalJSON implements the json.Unmarshaler interface and deserializes the Slice from a JSON array